from typing import Any
from universal_mcp.applications import APIApplication
from universal_mcp.integrations import Integration

class ComplexApiApp(APIApplication):
    def __init__(self, integration: Integration = None, **kwargs) -> None:
        super().__init__(name='complexapiapp', integration=integration, **kwargs)
        self.base_url = ""

    def list_users(self, ) -> Any:
        """
        Retrieves a list of users from the API endpoint.
        
        Args:
            None: This function takes no arguments
        
        Returns:
            A JSON-decoded object containing the list of users returned by the API.
        
        Raises:
            requests.HTTPError: If the HTTP request returned an unsuccessful status code.
        
        Tags:
            list, users, api, fetch, important
        """
        url = f"{self.base_url}/users"
        query_params = {}
        response = self._get(url, params=query_params)
        response.raise_for_status()
        return response.json()

    def create_user(self, ) -> Any:
        """
        Creates a new user by sending a POST request to the users endpoint.
        
        Returns:
            The JSON response from the API containing the created user's information.
        
        Raises:
            HTTPError: Raised when the HTTP request returns an unsuccessful status code through the raise_for_status() method.
        
        Tags:
            create, user, post, api, important
        """
        url = f"{self.base_url}/users"
        query_params = {}
        response = self._post(url, data={}, params=query_params)
        response.raise_for_status()
        return response.json()

    def get_user(self, id) -> Any:
        """
        Retrieve details of a user by their unique identifier.
        
        Args:
            id: The unique identifier of the user to retrieve. Must not be None.
        
        Returns:
            A dictionary containing the user's details as parsed from the JSON response.
        
        Raises:
            ValueError: If the 'id' parameter is None.
            requests.HTTPError: If the HTTP request to retrieve the user fails.
        
        Tags:
            get, user, api, important
        """
        if id is None:
            raise ValueError("Missing required parameter 'id'")
        url = f"{self.base_url}/users/{id}"
        query_params = {}
        response = self._get(url, params=query_params)
        response.raise_for_status()
        return response.json()

    def list_tools(self):
        return [
            self.list_users,
            self.create_user,
            self.get_user
        ]
